<?php
/**
 * Customizer - Color Utils
 * 
 * @package Struninn UI Cards - Pricing Table
 * 
 * @since 1.0.0
 * 
 * @author Odin Design Themes (https://odindesignthemes.com/)
 * 
 */

if (!function_exists('struninnuicards_pricingtable_customizer_color_options_get')) {
  /**
   * Returns color settings.
   * 
   * @since 1.0.0
   * 
   * @param string $preset              Color preset, one of: 'light', 'dark'. Default: 'light'. 
   * @return array $color_settings      Color settings.
   */
  function struninnuicards_pricingtable_customizer_color_options_get($preset = 'light') {
    $color_settings = [
      'global'  => [
        /**
         * Tag
         */
        '--struninnuicard-pricingtable-tag-icon-color'              => [
          'label'   => esc_html_x('Tag Icon', '(Customizer) Color Option - Label', 'struninnuicards_pricingtable'),
          'type'    => 'color',
          'default' => '#ff5794'
        ],
        '--struninnuicard-pricingtable-tag-solid-foreground-color'  => [
          'label'   => esc_html_x('Tag Solid Foreground', '(Customizer) Color Option - Label', 'struninnuicards_pricingtable'),
          'type'    => 'color',
          'default' => '#ffffff'
        ],
        '--struninnuicard-pricingtable-tag-solid-background-color'  => [
          'label'   => esc_html_x('Tag Solid Background', '(Customizer) Color Option - Label', 'struninnuicards_pricingtable'),
          'type'    => 'color',
          'default' => '#5c8cfb'
        ]
      ],
      'light'   => [
        /**
         * Box
         */
        '--struninnuicard-pricingtable-light-background-color'     => [
          'label'   => esc_html_x('Box Background', '(Customizer) Color Option - Label', 'struninnuicards_pricingtable'),
          'type'    => 'color',
          'default' => '#ffffff'
        ],
        '--struninnuicard-pricingtable-light-background-alt-color' => [
          'label'   => esc_html_x('Darker Box Background', '(Customizer) Color Option - Label', 'struninnuicards_pricingtable'),
          'type'    => 'color',
          'default' => '#f9f9f9'
        ],

        /**
         * Lines
         */
        '--struninnuicard-pricingtable-light-line-color'    => [
          'label'   => esc_html_x('Line', '(Customizer) Color Option - Label', 'struninnuicards_pricingtable'),
          'type'    => 'color',
          'default' => '#e1e1e1'
        ],

        /**
         * Text
         */
        '--struninnuicard-pricingtable-light-text-color'    => [
          'label'   => esc_html_x('Text', '(Customizer) Color Option - Label', 'struninnuicards_pricingtable'),
          'type'    => 'color',
          'default' => '#22212c'
        ],

        /**
         * Button
         */
        '--struninnuicard-pricingtable-light-button-text-color'       => [
          'label'   => esc_html_x('Button Text', '(Customizer) Color Option - Label', 'struninnuicards_pricingtable'),
          'type'    => 'color',
          'default' => '#ffffff'
        ],
        '--struninnuicard-pricingtable-light-button-background-color' => [
          'label'   => esc_html_x('Button Background', '(Customizer) Color Option - Label', 'struninnuicards_pricingtable'),
          'type'    => 'color',
          'default' => '#22212c'
        ]
      ],
      'dark'  => [
        /**
         * Box
         */
        '--struninnuicard-pricingtable-dark-background-color'     => [
          'label'   => esc_html_x('Box Background', '(Customizer) Color Option - Label', 'struninnuicards_pricingtable'),
          'type'    => 'color',
          'default' => '#2b2a3b'
        ],
        '--struninnuicard-pricingtable-dark-background-alt-color' => [
          'label'   => esc_html_x('Darker Box Background', '(Customizer) Color Option - Label', 'struninnuicards_pricingtable'),
          'type'    => 'color',
          'default' => '#21202e'
        ],

        /**
         * Lines
         */
        '--struninnuicard-pricingtable-dark-line-color'    => [
          'label'   => esc_html_x('Line', '(Customizer) Color Option - Label', 'struninnuicards_pricingtable'),
          'type'    => 'color',
          'default' => '#38374b'
        ],

        /**
         * Text
         */
        '--struninnuicard-pricingtable-dark-text-color'    => [
          'label'   => esc_html_x('Text', '(Customizer) Color Option - Label', 'struninnuicards_pricingtable'),
          'type'    => 'color',
          'default' => '#ffffff'
        ],

        /**
         * Button
         */
        '--struninnuicard-pricingtable-dark-button-text-color'       => [
          'label'   => esc_html_x('Button Text', '(Customizer) Color Option - Label', 'struninnuicards_pricingtable'),
          'type'    => 'color',
          'default' => '#ffffff'
        ],
        '--struninnuicard-pricingtable-dark-button-background-color' => [
          'label'   => esc_html_x('Button Background', '(Customizer) Color Option - Label', 'struninnuicards_pricingtable'),
          'type'    => 'color',
          'default' => '#22212c'
        ]
      ]
    ];

    return $color_settings[$preset];
  }
}

if (!function_exists('struninnuicards_pricingtable_customizer_color_styles_get')) {
  /**
   * Returns current color style variables.
   * 
   * @since 1.0.0
   * 
   * @return string $color_styles      Current color style variables.
   */
  function struninnuicards_pricingtable_customizer_color_styles_get() {
    $color_presets = ['light', 'dark'];

    $current_color_options = [];

    foreach ($color_presets as $color_preset) {
      $current_color_options = array_merge($current_color_options, struninnuicards_pricingtable_customizer_color_options_get($color_preset));
    }

    $custom_user_colors = get_option('struninnuicards_pricingtable_color', []);

    foreach ($current_color_options as $color_name => $color_data) {
      $user_entered_custom_color = array_key_exists($color_name, $custom_user_colors);

      // if user entered a color for this, use it
      if ($user_entered_custom_color) {
        $color_value = $custom_user_colors[$color_name];
      } else {
      // set color default otherwise
        $color_value = $color_data['default'];
      }
      
      $custom_user_colors[$color_name] = $color_value;
    }

    $color_styles = ':root {';

    foreach ($custom_user_colors as $color_name => $color_value) {
      $color_styles .= $color_name . ': ' . $color_value . ';';
    }

    $color_styles .= '}';

    return $color_styles;
  }
}

?>