<?php
/**
 * Functions - Elementor
 * 
 * @package Struninn UI Cards - Pricing Table
 * 
 * @since 1.0.0
 * 
 * @author Odin Design Themes (https://odindesignthemes.com/)
 * 
 */
if (!function_exists('struninnuicards_pricingtable_elementor_widgets_register')) {
  /**
   * Registers Elementor widgets.
   * 
   * @since 1.0.0
   * 
   * @param object $widgets_manager     Elementot widgets manager instance.
   */
  function struninnuicards_pricingtable_elementor_widgets_register($widgets_manager) {
    require_once STRUNINNUICARDS_PRICINGTABLE_PATH . 'includes/functions/elementor/widgets/pricingtable-card/StruninnUICards_Elementor_Widget_PricingTable_Card_V1.php';
    require_once STRUNINNUICARDS_PRICINGTABLE_PATH . 'includes/functions/elementor/widgets/pricingtable-card/StruninnUICards_Elementor_Widget_PricingTable_Card_V2.php';
    require_once STRUNINNUICARDS_PRICINGTABLE_PATH . 'includes/functions/elementor/widgets/pricingtable-card/StruninnUICards_Elementor_Widget_PricingTable_Card_V3.php';
    require_once STRUNINNUICARDS_PRICINGTABLE_PATH . 'includes/functions/elementor/widgets/pricingtable-card/StruninnUICards_Elementor_Widget_PricingTable_Card_V4.php';
    require_once STRUNINNUICARDS_PRICINGTABLE_PATH . 'includes/functions/elementor/widgets/pricingtable-card/StruninnUICards_Elementor_Widget_PricingTable_Card_V5.php';

    $widgets_manager->register(new StruninnUICards_Elementor_Widget_PricingTable_Card_V1());
    $widgets_manager->register(new StruninnUICards_Elementor_Widget_PricingTable_Card_V2());
    $widgets_manager->register(new StruninnUICards_Elementor_Widget_PricingTable_Card_V3());
    $widgets_manager->register(new StruninnUICards_Elementor_Widget_PricingTable_Card_V4());
    $widgets_manager->register(new StruninnUICards_Elementor_Widget_PricingTable_Card_V5());
  }
}

add_action('elementor/widgets/register', 'struninnuicards_pricingtable_elementor_widgets_register');

if (!function_exists('struninnuicards_elementor_widget_categories_register')) {
  /**
   * Registers Elementor categories.
   * 
   * @since 1.0.0
   * 
   * @param object $elements_manager      Elementor elements manager instance.
   */
  function struninnuicards_elementor_widget_categories_register($elements_manager) {
    $elements_manager->add_category(
      'struninnuicards',
      [
        'title' => esc_html__('Struninn UI Cards', 'struninnuicards_pricingtable')
      ]
    );
  }
}

add_action('elementor/elements/categories_registered', 'struninnuicards_elementor_widget_categories_register');

if (!function_exists('struninnuicards_pricingtable_elementor_card_features_option_encode')) {
  /**
   * Encodes card features option value to be compatible with Elementor SWITCHER control.
   * 
   * @since 1.0.0
   * 
   * @param array   $features               Card features.
   * @return array  $encoded_features       Card encoded features.
   */
  function struninnuicards_pricingtable_elementor_card_features_option_encode($features) {
    $encoded_features = [];

    foreach ($features as $feature) {
      $feature_item = array_merge([], $feature);
      $feature_item['enabled'] = $feature_item['enabled'] === true ? 'yes' : 'no';
      $encoded_features[] = $feature_item;
    }

    return $encoded_features;
  }
}

if (!function_exists('struninnuicards_pricingtable_elementor_card_features_option_decode')) {
  /**
   * Decodes Elementor SWITCHER control card features option values.
   * 
   * @since 1.0.0
   * 
   * @param array   $encoded_features       Card encoded features.
   * @return array  $decoded_features       Card decoded features.
   */
  function struninnuicards_pricingtable_elementor_card_features_option_decode($encoded_features) {
    $decoded_features = [];

    foreach ($encoded_features as $feature) {
      $feature_item = array_merge([], $feature);
      $feature_item['enabled'] = $feature_item['enabled'] === 'yes';
      $decoded_features[] = $feature_item;
    }

    return $decoded_features;
  }
}