<?php
/**
 * Functions - Elementor - Widget
 * 
 * @package Struninn UI Cards - Pricing Table
 * 
 * @since 1.0.0
 * 
 * @author Odin Design Themes (https://odindesignthemes.com/)
 * 
 */

if (!class_exists('StruninnUICards_Elementor_Widget_PricingTable_Card_V4')) {
  /**
   * Video List Elementor Widget.
   * 
   * @since 1.0.0
   */
  class StruninnUICards_Elementor_Widget_PricingTable_Card_V4 extends \Elementor\Widget_Base {
    public function __construct($data = [], $args = null) {
      parent::__construct($data, $args);

      wp_register_script('struninnuicards-elementor-widget-pricingtable-card', STRUNINNUICARDS_PRICINGTABLE_URL . 'js/elementor/widget/pricingtable-card/pricingtable-card.js', ['elementor-frontend'], '1.0.0', true);
    }

    public function get_name() {
      return 'struninnuicards_elementor_widget_pricingtable_card_v4';
    }
  
    public function get_title() {
      return esc_html__('Struninn UI Card - Pricing Table V4', 'struninnuicards_pricingtable');
    }
  
    public function get_icon() {
      return 'eicon-info-box';
    }
  
    public function get_categories() {
      return ['struninnuicards'];
    }
  
    public function get_keywords() {
      return ['struninn', 'struninnuicards', 'card', 'pricing'];
    }
  
    protected function register_controls() {
      $this->start_controls_section(
        'struninnuicards_pricingtable_card_content',
        [
          'label' => esc_html__('Content', 'struninnuicards_pricingtable'),
          'tab'   => \Elementor\Controls_Manager::TAB_CONTENT
        ]
      );

      $defaults = struninnuicards_pricingtable_template_card_v4_args_default_get();

      $this->add_control(
        'struninnuicards_pricingtable_card_theme',
        [
          'label'       => esc_html__('Theme', 'struninnuicards_pricingtable'),
          'type'        => \Elementor\Controls_Manager::SELECT,
          'default'     => $defaults['theme'],
          'options'     => [
            'light' => esc_html__('Light', 'struninnuicards_pricingtable'),
            'dark'  => esc_html__('Dark', 'struninnuicards_pricingtable')
          ]
        ]
      );

      $this->add_control(
        'struninnuicards_pricingtable_card_width',
        [
          'label'       => esc_html__('Width', 'struninnuicards_pricingtable'),
          'description' => esc_html__('Use a value of 0 to let the card auto adjust size.', 'struninnuicards_pricingtable'),
          'type'        => \Elementor\Controls_Manager::NUMBER,
          'min'         => 0,
          'step'        => 1,
          'default'     => $defaults['width']
        ]
      );

      $this->add_control(
        'struninnuicards_pricingtable_card_pattern_image',
        [
          'label'   => esc_html__('Pattern Background Image', 'struninnuicards_pricingtable'),
          'type'    => \Elementor\Controls_Manager::MEDIA,
          'default' => [
            'url' => $defaults['pattern_image_url']
          ]
        ]
      );

      $this->add_control(
        'struninnuicards_pricingtable_card_tier_image',
        [
          'label'   => esc_html__('Tier Image', 'struninnuicards_pricingtable'),
          'type'    => \Elementor\Controls_Manager::MEDIA,
          'default' => [
            'url' => $defaults['tier_image_url']
          ]
        ]
      );

      $this->add_control(
        'struninnuicards_pricingtable_card_title',
        [
          'label'       => esc_html__('Title', 'struninnuicards_pricingtable'),
          'type'        => \Elementor\Controls_Manager::TEXT,
          'input_type'  => 'text',
          'default'     => $defaults['title']
        ]
      );

      $this->add_control(
        'struninnuicards_pricingtable_card_price',
        [
          'label'       => esc_html__('Price', 'struninnuicards_pricingtable'),
          'type'        => \Elementor\Controls_Manager::TEXT,
          'input_type'  => 'text',
          'default'     => $defaults['price']
        ]
      );

      $this->add_control(
        'struninnuicards_pricingtable_card_period',
        [
          'label'       => esc_html__('Period', 'struninnuicards_pricingtable'),
          'type'        => \Elementor\Controls_Manager::TEXT,
          'input_type'  => 'text',
          'default'     => $defaults['period']
        ]
      );

      $this->add_control(
        'struninnuicards_pricingtable_card_text',
        [
          'label'       => esc_html__('Text', 'struninnuicards_pricingtable'),
          'type'        => \Elementor\Controls_Manager::TEXT,
          'input_type'  => 'text',
          'default'     => $defaults['text']
        ]
      );

      $this->add_control(
        'struninnuicards_pricingtable_card_button_text',
        [
          'label'       => esc_html__('Button Text', 'struninnuicards_pricingtable'),
          'type'        => \Elementor\Controls_Manager::TEXT,
          'input_type'  => 'text',
          'default'     => $defaults['button_text']
        ]
      );

      $this->add_control(
        'struninnuicards_pricingtable_card_button_link',
        [
          'label'       => esc_html__('Button Link', 'struninnuicards_pricingtable'),
          'type'        => \Elementor\Controls_Manager::URL,
          'options'     => false,
          'default'     => [
            'url' => $defaults['button_link']
          ]
        ]
      );

      $this->add_control(
        'struninnuicards_pricingtable_card_features',
        [
          'label'       => esc_html__('Features', 'struninnuicards_pricingtable'),
          'type'        => \Elementor\Controls_Manager::REPEATER,
          'prevent_empty' => false,
          'fields'      => [
            [
              'name'    => 'text',
              'label'   => esc_html__('Text', 'struninnuicards_pricingtable'),
              'type'    => \Elementor\Controls_Manager::TEXT,
              'default' => esc_html__('Feature Text', 'struninnuicards_pricingtable')
            ],
            [
              'name'          => 'enabled',
              'label'         => esc_html__('Enabled', 'struninnuicards_pricingtable'),
              'type'          => \Elementor\Controls_Manager::SWITCHER,
              'return_value'  => 'yes',
              'default'       => 'yes'
            ]
          ],
          'default' => struninnuicards_pricingtable_elementor_card_features_option_encode($defaults['features'])
        ]
      );

      $this->add_control(
        'struninnuicards_pricingtable_card_feature_status_tag_style',
        [
          'label'       => esc_html__('Feature Status Style', 'struninnuicards_pricingtable'),
          'description' => esc_html__('If you change the style between background and outline / regular types, the icons may seem to disappear, but its because the icons are the same color as the background. You can edit background and icon colors from the Style tab at the top.', 'struninnuicards_pricingtable'),
          'type'        => \Elementor\Controls_Manager::SELECT,
          'default'     => $defaults['feature_status_tag_style'],
          'options'     => [
            'regular'           => esc_html__('Regular', 'struninnuicards_pricingtable'),
            'background'        => esc_html__('Background', 'struninnuicards_pricingtable'),
            'background-round'  => esc_html__('Background Round', 'struninnuicards_pricingtable'),
            'outline'           => esc_html__('Outline', 'struninnuicards_pricingtable')
          ]
        ]
      );

      $this->end_controls_section();

      $this->start_controls_section(
        'struninnuicards_pricingtable_card_style',
        [
          'label' => esc_html__('Colors', 'struninnuicards_pricingtable'),
          'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ]
      );

      $this->add_control(
        'struninnuicards_pricingtable_cover_background_color_1',
        [
          'label'   => esc_html__('Cover Background Color 1', 'struninnuicards_pricingtable'),
          'type'    => \Elementor\Controls_Manager::COLOR,
          'default' => $defaults['cover_background_color_1']
        ]
      );

      $this->add_control(
        'struninnuicards_pricingtable_status_tag_enabled_icon_color',
        [
          'label'   => esc_html__('Feature Enabled Icon Color', 'struninnuicards_pricingtable'),
          'type'    => \Elementor\Controls_Manager::COLOR,
          'default' => $defaults['status_tag_enabled_icon_color']
        ]
      );

      $this->add_control(
        'struninnuicards_pricingtable_status_tag_enabled_background_color',
        [
          'label'   => esc_html__('Feature Enabled Background Color', 'struninnuicards_pricingtable'),
          'type'    => \Elementor\Controls_Manager::COLOR,
          'default' => $defaults['status_tag_enabled_background_color']
        ]
      );

      $this->add_control(
        'struninnuicards_pricingtable_status_tag_disabled_icon_color',
        [
          'label'   => esc_html__('Feature Disabled Icon Color', 'struninnuicards_pricingtable'),
          'type'    => \Elementor\Controls_Manager::COLOR,
          'default' => $defaults['status_tag_disabled_icon_color']
        ]
      );

      $this->add_control(
        'struninnuicards_pricingtable_status_tag_disabled_background_color',
        [
          'label'   => esc_html__('Feature Disabled Background Color', 'struninnuicards_pricingtable'),
          'type'    => \Elementor\Controls_Manager::COLOR,
          'default' => $defaults['status_tag_disabled_background_color']
        ]
      );

      $this->end_controls_section();
    }
  
    protected function render() {
      $settings = $this->get_settings_for_display();

      $features = struninnuicards_pricingtable_elementor_card_features_option_decode($settings['struninnuicards_pricingtable_card_features']);

      $args = [
        'theme'                                 => $settings['struninnuicards_pricingtable_card_theme'],
        'cover_background_color_1'              => $settings['struninnuicards_pricingtable_cover_background_color_1'],
        'status_tag_enabled_icon_color'         => $settings['struninnuicards_pricingtable_status_tag_enabled_icon_color'],
        'status_tag_enabled_background_color'   => $settings['struninnuicards_pricingtable_status_tag_enabled_background_color'],
        'status_tag_disabled_icon_color'        => $settings['struninnuicards_pricingtable_status_tag_disabled_icon_color'],
        'status_tag_disabled_background_color'  => $settings['struninnuicards_pricingtable_status_tag_disabled_background_color'],
        'width'                                 => $settings['struninnuicards_pricingtable_card_width'],
        'pattern_image_url'                     => $settings['struninnuicards_pricingtable_card_pattern_image']['url'],
        'tier_image_url'                        => $settings['struninnuicards_pricingtable_card_tier_image']['url'],
        'title'                                 => $settings['struninnuicards_pricingtable_card_title'],
        'price'                                 => $settings['struninnuicards_pricingtable_card_price'],
        'period'                                => $settings['struninnuicards_pricingtable_card_period'],
        'text'                                  => $settings['struninnuicards_pricingtable_card_text'],
        'button_text'                           => $settings['struninnuicards_pricingtable_card_button_text'],
        'button_link'                           => $settings['struninnuicards_pricingtable_card_button_link']['url'],
        'features'                              => $features,
        'feature_status_tag_style'              => $settings['struninnuicards_pricingtable_card_feature_status_tag_style']
      ];
    
      struninnuicards_pricingtable_template_card_v4($args);
    }

    public function get_script_depends() {
      return ['struninnuicards-elementor-widget-pricingtable-card'];
    }
  }
}

?>