<?php
/**
 * Functions - Template - Card V1
 * 
 * @package Struninn UI Cards - Pricing Table
 * 
 * @since 1.0.0
 * 
 * @author Odin Design Themes (https://odindesignthemes.com/)
 * 
 */

if (!function_exists('struninnuicards_pricingtable_template_card_v1_args_default_get')) {
  /**
   * Returns card v1 template default args.
   * 
   * @since 1.0.0
   * 
   * @return array $card_args_default        Default card v1 template args.
   */
  function struninnuicards_pricingtable_template_card_v1_args_default_get() {
    $card_args_default = [
      'theme'                                 => 'light',
      'cover_background_color_1'              => '#ffea2f',
      'cover_background_color_2'              => '#ff20e9',
      'cover_background_color_3'              => '#8f36ff',
      'cover_background_color_4'              => '#00e0ff',
      'status_tag_enabled_icon_color'         => '#ffffff',
      'status_tag_enabled_background_color'   => '#ff5794',
      'status_tag_disabled_icon_color'        => '#ffffff',
      'status_tag_disabled_background_color'  => '#22212c',
      'width'                                 => 0,
      'pattern_image_url'                     => '',
      'tier_image_url'                        => '',
      'tag_enabled'                           => true,
      'tag_style'                             => 'regular',
      'tag_text'                              => 'POPULAR!',
      'title'                                 => 'Legendary Tier',
      'price'                                 => '$120',
      'period'                                => 'month',
      'text'                                  => 'The perfect value for design studios and large businesses',
      'button_text'                           => 'Go Legendary',
      'button_link'                           => '#',
      'feature_status_tag_style'              => 'background-round',
      'features_title'                        => '',
      'features'                              => [
        [
          'text'    => 'Everything in Lower Tiers',
          'enabled' => true
        ],
        [
          'text'    => 'Up to 100 Team Members',
          'enabled' => true
        ],
        [
          'text'    => 'Unlimited Software Uses',
          'enabled' => true
        ],
        [
          'text'    => 'Access to the Legendary Pack',
          'enabled' => false
        ],
        [
          'text'    => '24/7 Dedicated Support',
          'enabled' => true
        ]
      ]
    ];

    return $card_args_default;
  }
}

if (!function_exists('struninnuicards_pricingtable_template_card_v1_get')) {
  /**
   * Returns card v1 template.
   * 
   * @since 1.0.0
   * 
   * @param array $args {
   *   @type string $theme                                    Card color scheme, one of: 'light', 'dark'.
   *   @type string $cover_background_color_1                 Cover background color 1.
   *   @type string $cover_background_color_2                 Cover background color 2.
   *   @type string $cover_background_color_3                 Cover background color 3.
   *   @type string $cover_background_color_4                 Cover background color 4.
   *   @type string $status_tag_enabled_icon_color            Status tag enabled icon color.
   *   @type string $status_tag_enabled_background_color      Status tag enabled background color.
   *   @type string $status_tag_disabled_icon_color           Status tag disabled icon color.
   *   @type string $status_tag_disabled_background_color     Status tag disabled background color.
   *   @type int    $width                                    Card width, a value of 0 to lets the card auto adjust size.
   *   @type string $pattern_image_url                        Card background pattern image URL.
   *   @type string $tier_image_url                           Card tier image url.
   *   @type bool   $tag_enabled                              True to display tag, false otherwise.
   *   @type string $tag_style                                Tag style, one of: 'regular', 'solid'.
   *   @type string $tag_text                                 Tag text.
   *   @type string $title                                    Title.
   *   @type string $price                                    Price.
   *   @type string $period                                   Period.
   *   @type string $text                                     Text.
   *   @type string $button_text                              Button text.
   *   @type string $button_link                              Button link URL.
   *   @type string $feature_status_tag_style                 Feature status tag style, one of: 'regular', 'background', 'background-round', 'outline'.
   *   @type string $features_title                           Features title.
   *   @type array  $features                                 {
   *     @type string $text         Feature text.
   *     @type bool   $enabled      True if feature is enabled, false otherwise.
   *   }
   * }
   * @return string $template                                 Card v1 HTML template.
   */
  function struninnuicards_pricingtable_template_card_v1_get($args = []) {
    $defaults = struninnuicards_pricingtable_template_card_v1_args_default_get();

    $options = array_merge($defaults, $args);

    $card_body_content_classes = '';

    if ($options['pattern_image_url'] === '') {
      $card_body_content_classes = ' card__body-content_no-cover';

      if ($options['tag_enabled'] && ($options['tier_image_url'] === '')) {
        $card_body_content_classes .= ' card__body-content_top-space';
      }
    } else if ($options['tier_image_url'] !== '') {
      $card_body_content_classes = ' card__body-content_cover';
    }

    global $struninnuicards_pricingtable_card_id;
    $struninnuicards_pricingtable_card_id++;

    ob_start();

  ?>
    <!-- STRUNINN UI CARD PRICING TABLE -->
    <div id="struninnuicard-pricingtable_card-<?php echo esc_attr($struninnuicards_pricingtable_card_id); ?>" class="struninnuicard-pricingtable struninnuicard-pricingtable_theme-<?php echo esc_attr($options['theme']); ?>">
    <?php if ($options['pattern_image_url'] !== '') : ?>
      <style>
        #struninnuicard-pricingtable_card-<?php echo esc_attr($struninnuicards_pricingtable_card_id); ?> .card__cover {
          background: url('<?php echo esc_url($options['pattern_image_url']); ?>') center center no-repeat, linear-gradient(135deg, <?php echo esc_attr($options['cover_background_color_1']); ?>, <?php echo esc_attr($options['cover_background_color_2']); ?> 34%, <?php echo esc_attr($options['cover_background_color_3']); ?> 69%, <?php echo esc_attr($options['cover_background_color_4']); ?>);
        }
      </style>
    <?php endif; ?>
      <!-- CARD -->
      <div class="card" style="--status-tag-enabled-icon-color: <?php echo esc_attr($options['status_tag_enabled_icon_color']); ?>; --status-tag-enabled-background-color: <?php echo esc_attr($options['status_tag_enabled_background_color']); ?>; --status-tag-disabled-icon-color: <?php echo esc_attr($options['status_tag_disabled_icon_color']); ?>; --status-tag-disabled-background-color: <?php echo esc_attr($options['status_tag_disabled_background_color']); ?>;<?php if ($options['width'] !== 0) : ?> max-width: <?php echo esc_attr($options['width']); ?>px;<?php endif; ?>">
        <!-- CARD BODY -->
        <div class="card__body">
        <?php

          if ($options['tag_enabled']) {
            /**
             * Card Tag
             */
            struninnuicards_pricingtable_template_tag([
              'style'     => $options['tag_style'],
              'text'      => $options['tag_text'],
              'icon'      => 'heart',
              'position'  => 'top right'
            ]);
          }
        
        ?>
        <?php if ($options['pattern_image_url'] !== '') : ?>
          <!-- CARD COVER -->
          <div class="card__cover"></div>
          <!-- /CARD COVER -->
        <?php endif; ?>

          <!-- CARD BODY CONTENT -->
          <div class="card__body-content card__body-content_centered<?php echo esc_attr($card_body_content_classes); ?>">
          <?php if ($options['tier_image_url'] !== '') : ?>
            <div class="card__circle">
              <div class="card__media card__tier-image-container_small">
                <img class="card__media-image" src="<?php echo esc_url($options['tier_image_url']); ?>" alt="">
              </div>
            </div>
          <?php endif; ?>

            <h2 class="card__title card__title_medium"><?php echo esc_html($options['title']); ?></h2>

          <?php if ($options['price'] !== '') : ?>
            <p class="card__pricing card__text">
              <span class="card__price card__price_small"><?php echo esc_html($options['price']); ?></span><?php if ($options['period'] !== '') : ?> / <?php echo esc_html($options['period']); endif; ?>
            </p>
          <?php endif; ?>

          <?php if ($options['button_text'] !== '') : ?>
            <a class="card__button card__button_solid" href="<?php echo esc_url($options['button_link']); ?>"><?php echo esc_html($options['button_text']); ?></a>
          <?php endif; ?>

          <?php if ($options['text'] !== '') : ?>
            <p class="card__text"><?php echo esc_html($options['text']); ?></p>
          <?php endif; ?>
          </div>
          <!-- /CARD BODY CONTENT -->

        <?php if (count($options['features']) > 0) : ?>
          <!-- CARD FEATURES -->
          <div class="card__features">
          <?php if ($options['features_title'] !== '') : ?>
            <p class="card__features-title"><?php echo esc_html($options['features_title']); ?></p>
          <?php endif; ?>
          <?php

            /**
             * Feature List
             */
            struninnuicards_pricingtable_template_feature_list([
              'items'               => $options['features'],
              'steps'               => true,
              'padded_items'        => true,
              'status_tag_style'    => $options['feature_status_tag_style'],
              'status_tag_position' => 'double'
            ]);

          ?>
          </div>
          <!-- /CARD FEATURES -->
        <?php endif; ?>
        </div>
        <!-- /CARD BODY -->
      </div>
      <!-- /CARD -->
    </div>
    <!-- /STRUNINN UI CARD PRICING TABLE -->
  <?php

    $template = ob_get_clean();

    return $template;
  }
}

if (!function_exists('struninnuicards_pricingtable_template_card_v1')) {
  /**
   * Prints card v1 template.
   * 
   * @since 1.0.0
   * 
   * @param array   $args           Card template args.
   */
  function struninnuicards_pricingtable_template_card_v1($args = []) {
    $template = struninnuicards_pricingtable_template_card_v1_get($args);

    $template_allowed_html = [
      'style' => [],
      'div'   => [
        'id'    => [],
        'class' => [],
        'style' => []
      ],
      'img'   => [
        'class' => [],
        'src'   => [],
        'alt'   => []
      ],
      'h2'    => [
        'class' => []
      ],
      'p'     => [
        'class' => []
      ],
      'span'  => [
        'class' => []
      ],
      'a'     => [
        'class'   => [],
        'href'    => [],
        'target'  => []
      ],
      'ul'    => [
        'class' => []
      ],
      'li'    => [
        'class' => []
      ],
      'svg'   => [
        'class' => []
      ],
      'use'   => [
        'href' => []
      ]
    ];
    
    echo wp_kses($template, $template_allowed_html);
  }
}