<?php
/**
 * Functions - Template - Card V4
 * 
 * @package Struninn UI Cards - Pricing Table
 * 
 * @since 1.0.0
 * 
 * @author Odin Design Themes (https://odindesignthemes.com/)
 * 
 */

if (!function_exists('struninnuicards_pricingtable_template_card_v4_args_default_get')) {
  /**
   * Returns card v4 template default args.
   * 
   * @since 1.0.0
   * 
   * @return array $card_args_default        Default card v4 template args.
   */
  function struninnuicards_pricingtable_template_card_v4_args_default_get() {
    $card_args_default = [
      'theme'                                 => 'light',
      'cover_background_color_1'              => '#9cb5cb',
      'status_tag_enabled_icon_color'         => '#88a6c1',
      'status_tag_enabled_background_color'   => '#22212c',
      'status_tag_disabled_icon_color'        => '#ff5794',
      'status_tag_disabled_background_color'  => '#22212c',
      'width'                                 => 0,
      'tier_image_url'                        => '',
      'pattern_image_url'                     => '',
      'title'                                 => 'Silver Tier',
      'price'                                 => '$15',
      'period'                                => 'month',
      'text'                                  => 'The perfect value for design studios and large businesses',
      'button_text'                           => 'Go Silver',
      'feature_status_tag_style'              => 'regular',
      'button_link'                           => '#',
      'features'                              => [
        [
          'text'    => 'Everything in Lower Tiers',
          'enabled' => true
        ],
        [
          'text'    => 'Up to 100 Team Members',
          'enabled' => true
        ],
        [
          'text'    => 'Unlimited Software Uses',
          'enabled' => true
        ],
        [
          'text'    => 'Access to the Legendary Pack',
          'enabled' => false
        ],
        [
          'text'    => '24/7 Dedicated Support',
          'enabled' => true
        ]
      ]
    ];

    return $card_args_default;
  }
}

if (!function_exists('struninnuicards_pricingtable_template_card_v4_get')) {
  /**
   * Returns card v4 template.
   * 
   * @since 1.0.0
   * 
   * @param array $args {
   *   @type string $theme                                    Card color scheme, one of: 'light', 'dark'.
   *   @type string $cover_background_color_1                 Cover background color 1.
   *   @type string $status_tag_enabled_icon_color            Status tag enabled icon color.
   *   @type string $status_tag_enabled_background_color      Status tag enabled background color.
   *   @type string $status_tag_disabled_icon_color           Status tag disabled icon color.
   *   @type string $status_tag_disabled_background_color     Status tag disabled background color.
   *   @type int    $width                                    Card width, a value of 0 to lets the card auto adjust size.
   *   @type string $pattern_image_url                        Card background pattern image URL.
   *   @type string $tier_image_url                           Card tier image url.
   *   @type string $title                                    Title.
   *   @type string $price                                    Price.
   *   @type string $period                                   Period.
   *   @type string $text                                     Text.
   *   @type string $button_text                              Button text.
   *   @type string $button_link                              Button link URL.
   *   @type string $feature_status_tag_style                 Feature status tag style, one of: 'regular', 'background', 'background-round', 'outline'.
   *   @type array  $features                                 {
   *     @type string $text         Feature text.
   *     @type bool   $enabled      True if feature is enabled, false otherwise.
   *   }
   * }
   * @return string $template                     Card v4 HTML template.
   */
  function struninnuicards_pricingtable_template_card_v4_get($args = []) {
    $defaults = struninnuicards_pricingtable_template_card_v1_args_default_get();

    $options = array_merge($defaults, $args);

    $card_body_content_classes = '';

    if ($options['pattern_image_url'] === '') {
      $card_body_content_classes = ' card__body-content_no-cover';
    } else if ($options['tier_image_url'] !== '') {
      $card_body_content_classes = ' card__body-content_cover';
    }

    global $struninnuicards_pricingtable_card_id;
    $struninnuicards_pricingtable_card_id++;

    ob_start();

  ?>
    <!-- STRUNINN UI CARD PRICING TABLE -->
    <div id="struninnuicard-pricingtable_card-<?php echo esc_attr($struninnuicards_pricingtable_card_id); ?>" class="struninnuicard-pricingtable struninnuicard-pricingtable_theme-<?php echo esc_attr($options['theme']); ?>">
    <?php if ($options['pattern_image_url'] !== '') : ?>
      <style>
        #struninnuicard-pricingtable_card-<?php echo esc_attr($struninnuicards_pricingtable_card_id); ?> .card__cover {
          background: url('<?php echo esc_url($options['pattern_image_url']); ?>') center center no-repeat, <?php echo esc_attr($options['cover_background_color_1']); ?>;
        }
      </style>
    <?php endif; ?>
      <!-- CARD -->
      <div class="card" style="--status-tag-enabled-icon-color: <?php echo esc_attr($options['status_tag_enabled_icon_color']); ?>; --status-tag-enabled-background-color: <?php echo esc_attr($options['status_tag_enabled_background_color']); ?>; --status-tag-disabled-icon-color: <?php echo esc_attr($options['status_tag_disabled_icon_color']); ?>; --status-tag-disabled-background-color: <?php echo esc_attr($options['status_tag_disabled_background_color']); ?>;<?php if ($options['width'] !== 0) : ?> max-width: <?php echo esc_attr($options['width']); ?>px;<?php endif; ?>">
        <!-- CARD BODY -->
        <div class="card__body">
        <?php if ($options['pattern_image_url'] !== '') : ?>
          <!-- CARD COVER -->
          <div class="card__cover card__cover_small"></div>
          <!-- /CARD COVER -->
        <?php endif; ?>

          <!-- CARD BODY CONTENT -->
          <div class="card__body-content card__body-content_small card__body-content_centered<?php echo esc_attr($card_body_content_classes); ?>">
          <?php if ($options['tier_image_url'] !== '') : ?>
            <?php if ($options['pattern_image_url'] !== '') : ?>
              <div class="card__tier-panel">
            <?php endif; ?>
              <div class="card__media card__tier-image-container_medium">
                <img class="card__media-image" src="<?php echo esc_url($options['tier_image_url']); ?>" alt="">
              </div>
            <?php if ($options['pattern_image_url'] !== '') : ?>
              </div>
            <?php endif; ?>
          <?php endif; ?>

            <h2 class="card__title card__title_medium"><?php echo esc_html($options['title']); ?></h2>

          <?php if ($options['text'] !== '') : ?>
            <p class="card__text"><?php echo esc_html($options['text']); ?></p>
          <?php endif; ?>
          </div>
          <!-- /CARD BODY CONTENT -->

        <?php if (count($options['features']) > 0) : ?>
          <!-- CARD FEATURES -->
          <div class="card__features card__features_bordered card__features_dark">
          <?php

            /**
             * Feature List
             */
            struninnuicards_pricingtable_template_feature_list([
              'items'             => $options['features'],
              'padded'            => true,
              'status_tag_style'  => $options['feature_status_tag_style']
            ]);

          ?>
          </div>
          <!-- /CARD FEATURES -->
        <?php endif; ?>

        <!-- CARD BODY CONTENT -->
        <div class="card__body-content card__body-content_centered card__body-content_compact">
        <?php if ($options['price'] !== '') : ?>
          <p class="card__pricing card__text card__text_short">
            <span class="card__price card__price_big"><?php echo esc_html($options['price']); ?></span><?php if ($options['period'] !== '') : ?><br> / <?php echo esc_html($options['period']); endif; ?>
          </p>
        <?php endif; ?>

        <?php if ($options['button_text'] !== '') : ?>
          <a class="card__button card__button_solid" href="<?php echo esc_url($options['button_link']); ?>"><?php echo esc_html($options['button_text']); ?></a>
        <?php endif; ?>
        </div>
        <!-- /CARD BODY CONTENT -->
        </div>
        <!-- /CARD BODY -->
      </div>
      <!-- /CARD -->
    </div>
    <!-- /STRUNINN UI CARD PRICING TABLE -->
  <?php

    $template = ob_get_clean();

    return $template;
  }
}

if (!function_exists('struninnuicards_pricingtable_template_card_v4')) {
  /**
   * Prints card v4 template.
   * 
   * @since 1.0.0
   * 
   * @param array   $args           Card template args.
   */
  function struninnuicards_pricingtable_template_card_v4($args = []) {
    $template = struninnuicards_pricingtable_template_card_v4_get($args);

    $template_allowed_html = [
      'style' => [],
      'div'   => [
        'id'    => [],
        'class' => [],
        'style' => []
      ],
      'img'   => [
        'class' => [],
        'src'   => [],
        'alt'   => []
      ],
      'h2'    => [
        'class' => []
      ],
      'p'     => [
        'class' => []
      ],
      'br'    => [],
      'span'  => [
        'class' => []
      ],
      'a'     => [
        'class'   => [],
        'href'    => [],
        'target'  => []
      ],
      'ul'    => [
        'class' => []
      ],
      'li'    => [
        'class' => []
      ],
      'svg'   => [
        'class' => []
      ],
      'use'   => [
        'href' => []
      ]
    ];
    
    echo wp_kses($template, $template_allowed_html);
  }
}