<?php
/**
 * Functions - Template - Card V5
 * 
 * @package Struninn UI Cards - Pricing Table
 * 
 * @since 1.0.0
 * 
 * @author Odin Design Themes (https://odindesignthemes.com/)
 * 
 */

if (!function_exists('struninnuicards_pricingtable_template_card_v5_args_default_get')) {
  /**
   * Returns card v5 template default args.
   * 
   * @since 1.0.0
   * 
   * @return array $card_args_default        Default card v5 template args.
   */
  function struninnuicards_pricingtable_template_card_v5_args_default_get() {
    $card_args_default = [
      'theme'                                 => 'light',
      'cover_background_color_1'              => '#ff7b1c',
      'status_tag_enabled_icon_color'         => '#00c27c',
      'status_tag_enabled_background_color'   => '#22212c',
      'status_tag_disabled_icon_color'        => '#ff5794',
      'status_tag_disabled_background_color'  => '#22212c',
      'width'                                 => 0,
      'tier_image_url'                        => '',
      'pattern_image_url'                     => '',
      'title'                                 => 'Bronze Tier',
      'price'                                 => 'Free',
      'period'                                => 'lifetime',
      'text'                                  => 'The perfect value for design studios and large businesses',
      'button_text'                           => 'Go Bronze',
      'button_link'                           => '#',
      'feature_status_tag_style'              => 'outline',
      'features_title'                        => 'YOU WILL GET:',
      'features'                              => [
        [
          'text'    => 'Everything in Lower Tiers',
          'enabled' => true
        ],
        [
          'text'    => 'Up to 100 Team Members',
          'enabled' => true
        ],
        [
          'text'    => 'Unlimited Software Uses',
          'enabled' => true
        ],
        [
          'text'    => 'Access to the Legendary Pack',
          'enabled' => false
        ],
        [
          'text'    => '24/7 Dedicated Support',
          'enabled' => true
        ]
      ]
    ];

    return $card_args_default;
  }
}

if (!function_exists('struninnuicards_pricingtable_template_card_v5_get')) {
  /**
   * Returns card v5 template.
   * 
   * @since 1.0.0
   * 
   * @param array $args {
   *   @type string $theme                                    Card color scheme, one of: 'light', 'dark'.
   *   @type string $cover_background_color_1                 Cover background color 1.
   *   @type string $status_tag_enabled_icon_color            Status tag enabled icon color.
   *   @type string $status_tag_enabled_background_color      Status tag enabled background color.
   *   @type string $status_tag_disabled_icon_color           Status tag disabled icon color.
   *   @type string $status_tag_disabled_background_color     Status tag disabled background color.
   *   @type int    $width                                    Card width, a value of 0 to lets the card auto adjust size.
   *   @type string $tier_image_url                           Card tier image url.
   *   @type string $pattern_image_url                        Card background pattern image URL.
   *   @type string $title                                    Title.
   *   @type string $price                                    Price.
   *   @type string $period                                   Period.
   *   @type string $text                                     Text.
   *   @type string $button_text                              Button text.
   *   @type string $button_link                              Button link URL.
   *   @type string $feature_status_tag_style                 Feature status tag style, one of: 'regular', 'background', 'background-round', 'outline'.
   *   @type string $features_title                           Features title.
   *   @type array  $features                                 {
   *     @type string $text         Feature text.
   *     @type bool   $enabled      True if feature is enabled, false otherwise.
   *   }
   * }
   * @return string $template                     Card v5 HTML template.
   */
  function struninnuicards_pricingtable_template_card_v5_get($args = []) {
    $defaults = struninnuicards_pricingtable_template_card_v5_args_default_get();

    $options = array_merge($defaults, $args);

    global $struninnuicards_pricingtable_card_id;
    $struninnuicards_pricingtable_card_id++;

    ob_start();

  ?>
    <!-- STRUNINN UI CARD PRICING TABLE -->
    <div id="struninnuicard-pricingtable_card-<?php echo esc_attr($struninnuicards_pricingtable_card_id); ?>" class="struninnuicard-pricingtable struninnuicard-pricingtable_theme-<?php echo esc_attr($options['theme']); ?><?php if ($options['button_text'] !== '') : ?> struninnuicard-pricingtable_footer-medium<?php endif; ?><?php if ($options['pattern_image_url'] !== '') : ?> struninnuicard-pricingtable_header<?php endif; ?>">
    <?php if ($options['pattern_image_url'] !== '') : ?>
      <style>
        #struninnuicard-pricingtable_card-<?php echo esc_attr($struninnuicards_pricingtable_card_id); ?> .card__header {
          background: url('<?php echo esc_url($options['pattern_image_url']); ?>') center center no-repeat, <?php echo esc_attr($options['cover_background_color_1']); ?>;
        }
      </style>
    <?php endif; ?>
      <!-- CARD -->
      <div class="card" style="--status-tag-enabled-icon-color: <?php echo esc_attr($options['status_tag_enabled_icon_color']); ?>; --status-tag-enabled-background-color: <?php echo esc_attr($options['status_tag_enabled_background_color']); ?>; --status-tag-disabled-icon-color: <?php echo esc_attr($options['status_tag_disabled_icon_color']); ?>; --status-tag-disabled-background-color: <?php echo esc_attr($options['status_tag_disabled_background_color']); ?>;<?php if ($options['width'] !== 0) : ?> max-width: <?php echo esc_attr($options['width']); ?>px;<?php endif; ?>">
      <?php if ($options['pattern_image_url'] !== '') : ?>
        <!-- CARD HEADER -->
        <div class="card__header card__media"></div>
        <!-- /CARD HEADER -->
      <?php endif; ?>

        <!-- CARD BODY -->
        <div class="card__body">
          <!-- CARD BODY CONTENT -->
          <div class="card__body-content card__body-content_hide-overflow">
            <!-- CARD ROW -->
            <div class="card__row">
            <?php if ($options['tier_image_url'] !== '') : ?>
              <div class="card__media card__tier-image-container_tiny">
                <img class="card__media-image" src="<?php echo esc_url($options['tier_image_url']); ?>" alt="">
              </div>
            <?php endif; ?>
              <h2 class="card__title"><?php echo esc_html($options['title']); ?></h2>
            </div>
            <!-- /CARD ROW -->

          <?php if ($options['text'] !== '') : ?>
            <p class="card__text card__summary"><?php echo esc_html($options['text']); ?></p>
          <?php endif; ?>

          <?php if ($options['price'] !== '') : ?>
            <p class="card__pricing card__text">
              <span class="card__price"><?php echo esc_html($options['price']); ?></span><?php if ($options['period'] !== '') : ?> / <?php echo esc_html($options['period']); endif; ?>
            </p>
          <?php endif; ?>
          </div>
          <!-- /CARD BODY CONTENT -->

        <?php if (count($options['features']) > 0) : ?>
          <!-- CARD FEATURES -->
          <div class="card__features card__features_bottom-space">
          <?php if ($options['features_title'] !== '') : ?>
            <p class="card__features-title"><?php echo esc_html($options['features_title']); ?></p>
          <?php endif; ?>
          <?php

            /**
             * Feature List
             */
            struninnuicards_pricingtable_template_feature_list([
              'items'               => $options['features'],
              'padded'              => true,
              'status_tag_style'    => $options['feature_status_tag_style']
            ]);

          ?>
          </div>
          <!-- /CARD FEATURES -->
        <?php endif; ?>
        </div>
        <!-- /CARD BODY -->

      <?php if ($options['button_text'] !== '') : ?>
        <!-- CARD FOOTER -->
        <div class="card__footer card__footer_button">
          <a class="card__button card__button_medium card__button_merged card__button_solid" href="<?php echo esc_url($options['button_link']); ?>"><?php echo esc_html($options['button_text']); ?></a>
        </div>
        <!-- /CARD FOOTER -->
      <?php endif; ?>
      </div>
      <!-- /CARD -->
    </div>
    <!-- /STRUNINN UI CARD PRICING TABLE -->
  <?php

    $template = ob_get_clean();

    return $template;
  }
}

if (!function_exists('struninnuicards_pricingtable_template_card_v5')) {
  /**
   * Prints card v5 template.
   * 
   * @since 1.0.0
   * 
   * @param array   $args           Card template args.
   */
  function struninnuicards_pricingtable_template_card_v5($args = []) {
    $template = struninnuicards_pricingtable_template_card_v5_get($args);

    $template_allowed_html = [
      'style' => [],
      'div'   => [
        'id'    => [],
        'class' => [],
        'style' => []
      ],
      'img'   => [
        'class' => [],
        'src'   => [],
        'alt'   => []
      ],
      'h2'    => [
        'class' => []
      ],
      'p'     => [
        'class' => []
      ],
      'span'  => [
        'class' => []
      ],
      'a'     => [
        'class'   => [],
        'href'    => [],
        'target'  => []
      ],
      'ul'    => [
        'class' => []
      ],
      'li'    => [
        'class' => []
      ],
      'svg'   => [
        'class' => []
      ],
      'use'   => [
        'href' => []
      ]
    ];
    
    echo wp_kses($template, $template_allowed_html);
  }
}