<?php
/**
 * Functions - Template - Part
 * 
 * @package Struninn UI Cards - Pricing Table
 * 
 * @since 1.0.0
 * 
 * @author Odin Design Themes (https://odindesignthemes.com/)
 * 
 */

if (!function_exists('struninnuicards_pricingtable_template_tag_get')) {
  /**
   * Returns tag template.
   * 
   * @since 1.0.0
   * 
   * @param array $args {
   *   @type string $text             Tag text.
   *   @type string $style            Tag style.
   *   @type string $target_date      Target date for countdown.
   *   @type string $position         Tag position relative to container, accepted values: 'top', 'bottom', 'center', 'left', 'right' (i.e. 'bottom center').
   * }
   * @return string $template         Tag HTML template.
   */
  function struninnuicards_pricingtable_template_tag_get($args = []) {
    ob_start();

    $defaults = [];

    $options = array_merge($defaults, $args);

    $wrapper_classes = [
      'tag'
    ];

    if (array_key_exists('style', $options)) {
      $wrapper_classes[] = 'tag_' . $options['style'];
    }

    if (array_key_exists('position', $options)) {
      $position_directions = explode(' ', $options['position']);
      $position_class = trim(array_reduce($position_directions, function ($carry, $item) { $carry .= 'tag_' . $item . ' '; return $carry; }));
      $wrapper_classes[] = $position_class;
    }

  ?>
    <!-- TAG -->
    <div class="<?php echo esc_attr(implode(' ', $wrapper_classes)); ?>">
    <?php

      if (array_key_exists('icon', $options)) {
        /**
         * Icon
         */
        struninnuicards_pricingtable_template_icon([
          'additional_wrapper_classes'  => 'tag__icon',
          'icon'                        => $options['icon']
        ]);
      }
      
    ?>
    <?php if (array_key_exists('text', $options)) : ?>
      <p class="tag__text"><?php echo esc_html($options['text']); ?></p>
    <?php endif; ?>
    </div>
    <!-- /TAG -->
  <?php

    $template = ob_get_clean();

    return $template;
  }
}

if (!function_exists('struninnuicards_pricingtable_template_tag')) {
  /**
   * Prints tag template.
   * 
   * @since 1.0.0
   */
  function struninnuicards_pricingtable_template_tag($args = []) {
    $template = struninnuicards_pricingtable_template_tag_get($args);

    $template_allowed_html = [
      'div' => [
        'class' => []
      ],
      'p' => [
        'class' => []
      ],
      'svg' => [
        'class' => []
      ],
      'use' => [
        'href' => []
      ]
    ];
    
    echo wp_kses($template, $template_allowed_html);
  }
}

if (!function_exists('struninnuicards_pricingtable_template_feature_list_get')) {
  /**
   * Returns feature list template.
   * 
   * @since 1.0.0
   * 
   * @param array $args {
   *   @type array  $items                  Feature list items.
   *   @type bool   $steps                  True to show steps.
   *   @type bool   $padded                 True to add padding on list.
   *   @type bool   $padded_items           True to add padding on list items.
   *   @type string $status_tag_style       Status tag style, one of: 'regular', 'background', 'background-round', 'outline'.
   *   @type string $status_tag_position    Status tag position, one of: 'left', 'right', 'double'.
   * }
   * @return string $template       Feature list HTML template.
   */
  function struninnuicards_pricingtable_template_feature_list_get($args = []) {
    ob_start();

    $defaults = [
      'steps'               => false,
      'padded'              => false,
      'padded_items'        => false,
      'status_tag_style'    => 'regular',
      'status_tag_position' => 'left'
    ];

    $options = array_merge($defaults, $args);

    $wrapper_classes = [
      'feature-list'
    ];

    if ($options['steps']) {
      $wrapper_classes[] = 'feature-list_steps';
    }

    if ($options['padded']) {
      $wrapper_classes[] = 'feature-list_padded';
    }

    $status_tag_args = [];

    switch ($options['status_tag_style']) {
      case 'background-round':
        $status_tag_args['background'] = true;
        break;
      case 'background':
        $status_tag_args['background'] = true;
        $status_tag_args['radius'] = true;
        break;
      case 'outline':
        $status_tag_args['outline'] = true;
        break;
    }

    if (count($options['items']) > 0) {
  ?>
    <!-- FEATURE LIST -->
    <ul class="<?php echo esc_attr(implode(' ', $wrapper_classes)); ?>">
    <?php foreach ($options['items'] as $index => $feature) : ?>
    <?php 

      $feature_item_classes = '';

      if ($options['padded_items']) {
        $feature_item_classes = ' feature-list__item_padded';
      }

      if (in_array($options['status_tag_position'], ['right', 'double'])) {
        $feature_item_classes .= ' feature-list__item_space-between';
      }

      if ($options['steps'] && ($index === 0)) {
        $feature_item_classes .= ' feature-list__item_bordered';
      }

      $status_tag_args['enabled'] = $feature['enabled'];

    ?>
      <!-- FEATURE LIST ITEM -->
      <li class="feature-list__item<?php echo esc_attr($feature_item_classes); ?>">
      <?php

        if (in_array($options['status_tag_position'], ['left', 'double'])) {
          /**
           * Status Tag
           */
          struninnuicards_pricingtable_template_status_tag($status_tag_args);
        }

      ?>
        <p class="feature-list__text"><?php echo esc_html($feature['text']); ?></p>
      <?php

        if (in_array($options['status_tag_position'], ['right', 'double'])) {
          /**
           * Status Tag
           */
          struninnuicards_pricingtable_template_status_tag($status_tag_args);
        }

      ?>
      </li>
      <!-- /FEATURE LIST ITEM -->
    <?php endforeach; ?>
    </ul>
    <!-- /FEATURE LIST -->
  <?php
    }

    $template = ob_get_clean();

    return $template;
  }
}

if (!function_exists('struninnuicards_pricingtable_template_feature_list')) {
  /**
   * Prints feature list template.
   * 
   * @since 1.0.0
   */
  function struninnuicards_pricingtable_template_feature_list($args = []) {
    $template = struninnuicards_pricingtable_template_feature_list_get($args);

    $template_allowed_html = [
      'div' => [
        'class' => []
      ],
      'ul'  => [
        'class' => []
      ],
      'li'  => [
        'class' => []
      ],
      'p'   => [
        'class' => []
      ],
      'svg' => [
        'class' => []
      ],
      'use' => [
        'href' => []
      ]
    ];
    
    echo wp_kses($template, $template_allowed_html);
  }
}

if (!function_exists('struninnuicards_pricingtable_template_status_tag_get')) {
  /**
   * Returns status tag template.
   * 
   * @since 1.0.0
   * 
   * @param array $args {
   *   @type bool $enabled          True to show tick, false to show cross.
   *   @type bool $outline          True to show outline, false otherwise.
   *   @type bool $background       True to add a background, false otherwise.
   *   @type bool $radius           True to add soft border radius, false otherwise.
   * }
   * @return string $template       Status tag HTML template.
   */
  function struninnuicards_pricingtable_template_status_tag_get($args = []) {
    ob_start();

    $defaults = [
      'enabled' => true
    ];

    $options = array_merge($defaults, $args);

    $wrapper_classes = [
      'status-tag'
    ];

    if (array_key_exists('enabled', $options)) {
      if ($options['enabled']) {
        $wrapper_classes[] = 'status-tag_enabled';
      } else {
        $wrapper_classes[] = 'status-tag_disabled';
      }
    }

    if (array_key_exists('outline', $options)) {
      $wrapper_classes[] = 'status-tag_outline';
    }

    if (array_key_exists('background', $options)) {
      $wrapper_classes[] = 'status-tag_background';
    }

    if (array_key_exists('radius', $options)) {
      $wrapper_classes[] = 'status-tag_radius';
    }

  ?>
    <!-- STATUS TAG -->
    <div class="<?php echo esc_attr(implode(' ', $wrapper_classes)); ?>">
    <?php

      /**
       * Icon
       */
      struninnuicards_pricingtable_template_icon([
        'additional_wrapper_classes'  => 'status-tag__icon',
        'icon'                        => $options['enabled'] ? 'tick' : 'cross'
      ]);
      
    ?>
    </div>
    <!-- /STATUS TAG -->
  <?php

    $template = ob_get_clean();

    return $template;
  }
}

if (!function_exists('struninnuicards_pricingtable_template_status_tag')) {
  /**
   * Prints status tag template.
   * 
   * @since 1.0.0
   */
  function struninnuicards_pricingtable_template_status_tag($args = []) {
    $template = struninnuicards_pricingtable_template_status_tag_get($args);

    $template_allowed_html = [
      'div' => [
        'class' => []
      ],
      'svg' => [
        'class' => []
      ],
      'use' => [
        'href' => []
      ]
    ];
    
    echo wp_kses($template, $template_allowed_html);
  }
}

if (!function_exists('struninnuicards_pricingtable_template_icon_get')) {
  /**
   * Returns icon template.
   * 
   * @since 1.0.0
   * 
   * @param array $args {
   *   @type string $additional_wrapper_classes       Classes to add to the wrapper.
   * }
   * @return string $template                         Icon HTML template.
   */
  function struninnuicards_pricingtable_template_icon_get($args = []) {
    ob_start();

    $defaults = [
      'additional_wrapper_classes'  => false
    ];

    $options = array_merge($defaults, $args);

    $wrapper_classes = [
      'icon_'. $options['icon']
    ];

    if ($options['additional_wrapper_classes']) {
      $wrapper_classes[] = $options['additional_wrapper_classes'];
    }

  ?>
    <!-- ICON -->
    <svg class="<?php echo esc_attr(implode(' ', $wrapper_classes)); ?>">
      <use href="#svg-<?php echo esc_attr($options['icon']); ?>"></use>
    </svg>
    <!-- ICON -->
  <?php

    $template = ob_get_clean();

    return $template;
  }
}

if (!function_exists('struninnuicards_pricingtable_template_icon')) {
  /**
   * Prints icon template.
   * 
   * @since 1.0.0
   */
  function struninnuicards_pricingtable_template_icon($args = []) {
    $template = struninnuicards_pricingtable_template_icon_get($args);

    $template_allowed_html = [
      'svg' => [
        'class' => []
      ],
      'use' => [
        'href' => []
      ]
    ];
    
    echo wp_kses($template, $template_allowed_html);
  }
}

?>